========
Plotting
========

.. currentmodule:: hiperwalk

Functions
---------
.. autosummary::
    :toctree: generated
    :nosignatures:

    plot_probability_distribution
    plot_success_probability
    plot_function
    plot_optimal_runtime
    plot_max_success_probability
